import QtQuick 1.1
import "utils.js" as Utils

OverviewPage {
	id: root

	property variant sys: theSystem

	title: qsTr("Overview")

	OverviewBox {
		id: acInBox

		width: 148
		height: 100
		title: getAcSourceName(sys.acSource)
		titleColor: "#E74c3c"
		color: "#C0392B"
		anchors {
			top: root.top; topMargin: 1
			left: parent.left; leftMargin: 5
		}

		values:	OverviewAcValues {
			connection: sys.grid
		}

		MbIcon {
			iconId: getAcSourceIcon(sys.acSource)
			anchors {
				bottom: parent.bottom
				left: parent.left; leftMargin: 2
			}
			opacity: 0.5
		}
	}

	OverviewBox {
		id: acLoadBox
		title: qsTr("AC Loads")
		color: "#27AE60"
		titleColor: "#2ECC71"
		width: 148
		height: 100

		anchors {
			horizontalCenter: parent.horizontalCenter
			top: root.top; topMargin: 1
		}

		values:	OverviewAcValues {
			connection: sys.acInLoad
		}
	}

	OverviewBox {
		id: acOutputBox
		title: qsTr("Critical Loads")
		color: "#157894"
		titleColor: "#419FB9"
		height: 100
		width: 148
		anchors {
			right: root.right; rightMargin: 5
			top: root.top; topMargin: 17
		}

		values:	OverviewAcValues {
			connection: sys.acOutLoad
		}
	}

	Multi {
		id: multi
		iconId: "overview-inverter-short"
		anchors {
			horizontalCenter: parent.horizontalCenter
			bottom: root.bottom; bottomMargin: 39
		}
	}

	// invisible item to connection all AC connections to..
	Item {
		id: acBus
		height: 10
		anchors {
			left: acInBox.left; leftMargin: 5
			right: acLoadBox.right; rightMargin: 2
			bottom: acInBox.bottom; bottomMargin: -15
		}
	}

	Battery {
		id: battery

		soc: sys.battery.soc.valid ? sys.battery.soc.value : 0
		height: pvInverterOnGrid.visible ? 81 : 101
		width: 145

		anchors {
			bottom: parent.bottom; bottomMargin: 5;
			left:parent.left; leftMargin: 5
		}
		values: Column {
			y: pvInverterOnGrid.visible ? 0 : 8
			width: parent.width

			TileText {
				text: sys.battery.soc.valid ? sys.battery.soc.value.toFixed(0) : "--"
				font.pixelSize: 30

				Text {
					anchors {
						bottom: parent.bottom; bottomMargin: 4
						horizontalCenter: parent.horizontalCenter; horizontalCenterOffset: parent.paintedWidth / 2 + 5
					}
					visible: sys.battery.soc.valid
					text: "%"
					color: "white"
					font.bold: true
				}
			}
			TileText {
				text: sys.battery.power.format(0)
			}
			TileText {
				text: sys.battery.voltage.format(1) + " · " + sys.battery.current.absFormat(1)
			}
		}
	}

	OverviewSolarInverter {
		id: pvInverterOnGrid
		title: qsTr("PV Inverter")
		width: 148
		height: 60
		visible: sys.pvOnGrid.power.valid
		showInverterIcon: false
		values: TileText {
			y: 2
			text: sys.pvOnGrid.power.format(0)
			font.pixelSize: 20
		}
		anchors {
			bottom: battery.top; bottomMargin: 5
			left: root.left; leftMargin: 5
		}
	}

	OverviewSolarInverter {
		id: pvInverterOnAcOut
		title: qsTr("PV Inverter")
		width: 148
		height: 60
		visible: sys.pvOnAcOut.power.valid
		showInverterIcon: false

		values: TileText {
			y: 2
			text: sys.pvOnAcOut.power.format(0)
			font.pixelSize: 20
		}
		anchors {
			bottom: blueSolarCharger.top; bottomMargin: 5
			right: parent.right; rightMargin: 5
		}
	}

	OverviewSolarCharger {
		id: blueSolarCharger
		title: qsTr("PV Charger")
		width: 148
		height: 60
		visible: sys.pvCharger.power.valid
		showChargerIcon: false

		anchors {
			right: root.right; rightMargin: 5
			bottom: root.bottom; bottomMargin: 5;
		}

		values: TileText {
			y: 2
			text: sys.pvCharger.power.format(0)
			font.pixelSize: 20
		}
	}

	// AC source power flow
	OverviewConnection {
		id: acSource
		ballCount: 4
		path: corner
		active: root.active
		value: flow(sys.grid ? sys.grid.power : undefined) * -1
		startPointVisible: false

		anchors {
			right: acInBox.left; rightMargin: -9
			left: pvInverterOnGridConnection.horizontalCenter
			bottom: acInBox.bottom; bottomMargin: 8
			top: acBus.verticalCenter
		}
	}

	// Coupled AC sources
	OverviewConnection {
		id: coupledAcConnection

		property VBusItem coupled: VBusItem {
			property double gridPower: sys.grid.power.valid ? sys.grid.power.value : 0
			property double pvPower: sys.pvOnGrid.power.valid ? sys.pvOnGrid.power.value : 0
			value: gridPower + pvPower
		}

		ballCount: 1
		path: straight
		active: root.active
		value: flow(coupled)
		startPointVisible: false
		endPointVisible: false

		anchors {
			left: pvInverterOnGridConnection.right
			right: vebusConnection.left
			top: acBus.verticalCenter
			bottom: acBus.verticalCenter
		}
	}

	// Grid inverter power flow
	OverviewConnection {
		id: pvInverterOnGridConnection
		ballCount: 1
		path: straight
		active: root.active && pvInverterOnGrid.visible
		value: flow(sys.pvOnGrid ? sys.pvOnGrid.power : undefined) * -1
		startPointVisible: false

		anchors {
			top: acBus.verticalCenter
			bottom: pvInverterOnGrid.top; bottomMargin: -8
			left: pvInverterOnGrid.right; leftMargin: -8
		}
	}

	// power to loads
	OverviewConnection {
		id: loadConnection
		ballCount: 3
		path: corner
		active: root.active
		value: flow(sys.acInLoad.power)
		startPointVisible: false
		endPointVisible: true

		anchors {
			right: acLoadBox.right; rightMargin: 10
			left: vebusConnection.horizontalCenter
			top: acBus.verticalCenter; bottomMargin: 6
			bottom: acLoadBox.bottom
		}
	}

	// Towards vebus system
	OverviewConnection {
		id: vebusConnection

		property VBusItem vebusAcPower: VBusItem { bind: [sys.vebusPrefix, "/Ac/ActiveIn/P"] }

		ballCount: 1
		path: straight
		active: root.active
		value: flow(vebusAcPower)
		startPointVisible: false
		endPointVisible: true

		anchors {
			left: multi.left; leftMargin: 8
			top: acBus.verticalCenter
			bottom: multi.top; bottomMargin: -7
		}
	}

	// AC out connection
	OverviewConnection {
		id: acOutConnection
		property VBusItem vebusAcPower: VBusItem { bind: [sys.vebusPrefix, "/Ac/Out/P"] }

		ballCount: 1
		path: straight
		active: root.active
		value: flow(vebusAcPower)
		endPointVisible: false

		anchors {
			left: multi.right; leftMargin: -8
			right: acOutBoxConnection.left
			top:  multi.top; topMargin: 8
		}
	}

	// UPS conenction
	OverviewConnection {
		id: acOutBoxConnection

		ballCount: 1
		path: straight
		active: root.active
		value: flow(sys.acOutLoad.power)
		startPointVisible: false

		anchors {
			left: acOutputBox.left; leftMargin: 10
			top: acOutConnection.verticalCenter
			bottom: acOutputBox.bottom; bottomMargin: 9
		}
	}

	// PV Inverter on AC out connection
	OverviewConnection {
		id: pvOnAcOutConnection

		ballCount: 1
		path: straight
		active: root.active && pvInverterOnAcOut.visible
		value: flow(sys.pvOnAcOut.power)
		endPointVisible: false

		anchors {
			left: acOutBoxConnection.left
			bottom: acOutConnection.verticalCenter
			top: pvInverterOnAcOut.top; topMargin: 8
		}
	}

	// DC connection from multi
	OverviewConnection {
		ballCount: 1
		path: straight
		active: root.active
		value: flow(sys.vebusDc.power)
		endPointVisible: false

		anchors {
			right: dcConnection.right;
			top:  multi.bottom; topMargin: -10
			bottom: dcConnection.top;
		}
	}

	// Battery to DC connection
	OverviewConnection {
		ballCount: 3
		path: straight
		active: root.active
		value: Utils.sign(noNoise(sys.pvCharger.power) + noNoise(sys.vebusDc.power))
		startPointVisible: false

		anchors {
			left: dcConnection.left;
			top: dcConnection.verticalCenter
			right: battery.right; rightMargin: 10
		}
	}

	// Solar charger to DC connection
	OverviewConnection {
		ballCount: 3
		path: straight
		active: root.active && blueSolarCharger.visible
		value: flow(sys.pvCharger.power)
		endPointVisible: false

		anchors {
			right: dcConnection.right;
			top: dcConnection.top
			left: blueSolarCharger.left; leftMargin: 10
		}
	}

	Item {
		id: dcConnection
		anchors {
			horizontalCenter: multi.horizontalCenter
			top: multi.bottom; topMargin: 10
		}
	}
}
