import QtQuick 1.1

MbPage {
	id: root

	property variant service
	property string bindPrefix
	// froniusInverterProductId should always be equal to VE_PROD_ID_PV_INVERTER_FRONIUS
	property int froniusInverterProductId: 0xA142
	// carloGavazziEmProductId should always be equal to VE_PROD_ID_CARLO_GAVAZZI_EM
	property int carloGavazziEmProductId: 0xB002

	title: service.description
	summary: acTotalPower.item.text

	function formatStatus(text, value)
	{
		return text + " (" + value.toString() + ")";
	}

	function formatCgErrorCode(value)
	{
		if (value === undefined)
			return "";
		var text = qsTr("No error");
		switch (value) {
		case 1:
			text = qsTr("Front selector locked");
			break;
		}
		return text + " (" + value.toString() + ")";
	}

	VBusItem {
		id: productIdItem
		bind: service.path("/ProductId")
	}

	VBusItem {
		id: cgErrorCode
		bind: productIdItem.value === carloGavazziEmProductId ? service.path("/ErrorCode") : ""
	}

	model: VisualItemModel {

		MbItemOptions {
			description: qsTr("Status")
			bind: productIdItem.value === froniusInverterProductId ? service.path("/StatusCode") : ""
			readonly: true
			show: productIdItem.value === froniusInverterProductId
			possibleValues: [
				MbOption { description: formatStatus(qsTr("Startup"), 0); value: 0 },
				MbOption { description: formatStatus(qsTr("Startup"), 1); value: 1 },
				MbOption { description: formatStatus(qsTr("Startup"), 2); value: 2 },
				MbOption { description: formatStatus(qsTr("Startup"), 3); value: 3 },
				MbOption { description: formatStatus(qsTr("Startup"), 4); value: 4 },
				MbOption { description: formatStatus(qsTr("Startup"), 5); value: 5 },
				MbOption { description: formatStatus(qsTr("Startup"), 6); value: 6 },
				MbOption { description: qsTr("Running"); value: 7 },
				MbOption { description: qsTr("Standby"); value: 8 },
				MbOption { description: qsTr("Boot loading"); value: 9 },
				MbOption { description: qsTr("Error"); value: 10 }
			]
		}

		MbItemValue {
			description: qsTr("Error Code")
			item.bind: show ? service.path("/ErrorCode") : ""
			show: productIdItem.value === froniusInverterProductId
		}

		MbItemValue {
			description: qsTr("Error Code")
			item.text: formatCgErrorCode(cgErrorCode.value)
			show: productIdItem.value === carloGavazziEmProductId
		}

		MbItemRow {
			description: qsTr("AC Phase L1")
			values: [
				MbTextBlock { item.bind: service.path("/Ac/L1/Voltage"); width: 80; height: 25 },
				MbTextBlock { item.bind: service.path("/Ac/L1/Current"); width: 100; height: 25 },
				MbTextBlock { item.bind: service.path("/Ac/L1/Power"); width: 120; height: 25 }
			]
		}

		MbItemRow {
			description: qsTr("AC Phase L2")
			values: [
				MbTextBlock { item.bind: service.path("/Ac/L2/Voltage"); width: 80; height: 25 },
				MbTextBlock { item.bind: service.path("/Ac/L2/Current"); width: 100; height: 25 },
				MbTextBlock { item.bind: service.path("/Ac/L2/Power"); width: 120; height: 25 }
			]
		}

		MbItemRow {
			description: qsTr("AC Phase L3")
			values: [
				MbTextBlock { item.bind: service.path("/Ac/L3/Voltage"); width: 80; height: 25 },
				MbTextBlock { item.bind: service.path("/Ac/L3/Current"); width: 100; height: 25 },
				MbTextBlock { item.bind: service.path("/Ac/L3/Power"); width: 120; height: 25 }
			]
		}

		MbItemRow {
			height: 70
			description: qsTr("AC Totals")
			values: MbColumn {
				MbRow {
					MbTextBlock { item.bind: service.path("/Ac/Current"); width: 100; height: 25 }
					MbTextBlock { id: acTotalPower; item.bind: service.path("/Ac/Power"); width: 120; height: 25 }
				}
				MbTextBlock { anchors.right: parent.right; item.bind: service.path("/Ac/Energy/Forward"); width: 120; height: 25 }
			}
		}

		MbItemValue {
			description: qsTr("Energy L1")
			item.bind: service.path("/Ac/L1/Energy/Forward")
		}

		MbItemValue {
			description: qsTr("Energy L2")
			item.bind: service.path("/Ac/L2/Energy/Forward")
		}

		MbItemValue {
			description: qsTr("Energy L3")
			item.bind: service.path("/Ac/L3/Energy/Forward")
		}

		MbItemValue {
			description: qsTr("Power limit")
			show: item.valid
			item.bind: service.path("/Ac/PowerLimit")
		}

		MbItemValue {
			description: qsTr("Maximum power")
			show: item.valid
			item.bind: service.path("/Ac/MaxPower")
		}

		MbSubMenu {
			description: qsTr("Device")
			subpage: Component {
				PageDeviceInfo {
					title: qsTr("Device")
					bindPrefix: root.bindPrefix
				}
			}
		}
	}
}
