import QtQuick 1.1
import com.victron.velib 1.0
import "utils.js" as Utils

MbPage {
	id: root
	property string bindPrefix

	model: VisualItemModel {
		MbItemValue {
			description: qsTr("Deepest discharge")
			item.bind: Utils.path(bindPrefix, "/History/DeepestDischarge")
		}

		MbItemValue {
			description: qsTr("Last discharge")
			item.bind: Utils.path(bindPrefix, "/History/LastDischarge")
		}

		MbItemValue {
			description: qsTr("Average discharge")
			item.bind: Utils.path(bindPrefix, "/History/AverageDischarge")
		}

		MbItemValue {
			description: qsTr("Total charge cycles")
			item.bind: Utils.path(bindPrefix, "/History/ChargeCycles")
		}

		MbItemValue {
			description: qsTr("Number of full discharges")
			item.bind: Utils.path(bindPrefix, "/History/FullDischarges")
		}

		MbItemValue {
			description: qsTr("Cumulative Ah drawn")
			item.bind: Utils.path(bindPrefix, "/History/TotalAhDrawn")
		}

		MbItemValue {
			description: qsTr("Minimum voltage")
			item.bind: Utils.path(bindPrefix, "/History/MinimumVoltage")
		}

		MbItemValue {
			description: qsTr("Maximum voltage")
			item.bind: Utils.path(bindPrefix, "/History/MaximumVoltage")
		}

		MbItemTimeSpan {
			description: qsTr("Time since last full charge")
			item.bind: Utils.path(bindPrefix, "/History/TimeSinceLastFullCharge")
		}

		MbItemValue {
			description: qsTr("Synchronisation count")
			item.bind: Utils.path(bindPrefix, "/History/AutomaticSyncs")
		}

		MbItemValue {
			description: qsTr("Low voltage alarms")
			item.bind: Utils.path(bindPrefix, "/History/LowVoltageAlarms")
			show: item.valid
		}

		MbItemValue {
			description: qsTr("High voltage alarms")
			item.bind: Utils.path(bindPrefix, "/History/HighVoltageAlarms")
			show: item.valid
		}

		MbItemValue {
			id: lowStarterVoltageAlarm
			VBusItem {
				id: hasStarterVoltage
				bind: Utils.path(bindPrefix, "/Settings/HasStarterVoltage")
			}
			description: qsTr("Low starter bat. voltage alarms")
			item.bind: show ? Utils.path(bindPrefix, "/History/LowStarterVoltageAlarms") : ""
			show: hasStarterVoltage.valid && hasStarterVoltage.value
		}

		MbItemValue {
			description: qsTr("High starter bat. voltage alarms")
			item.bind: show ? Utils.path(bindPrefix, "/History/HighStarterVoltageAlarms") : ""
			show: lowStarterVoltageAlarm.show
		}

		MbItemValue {
			description: qsTr("Minimum starter bat. voltage")
			item.bind: show ? Utils.path(bindPrefix, "/History/MinimumStarterVoltage") : ""
			show: lowStarterVoltageAlarm.show
		}

		MbItemValue {
			description: qsTr("Maximum starter bat. voltage")
			item.bind: show ? Utils.path(bindPrefix, "/History/MaximumStarterVoltage") : ""
			show: lowStarterVoltageAlarm.show
		}

		MbItemValue {
			description: qsTr("Discharged energy")
			item.bind: Utils.path(bindPrefix, "/History/DischargedEnergy")
			show: item.valid
		}

		MbItemValue {
			description: qsTr("Charged energy")
			item.bind: Utils.path(bindPrefix, "/History/ChargedEnergy")
			show: item.valid
		}

		MbItemText {
			text: qsTr("Info: Reset history on the monitor itself")
			show: !clearHistory.show
		}

		MbOK {
			id: clearHistory
			description: qsTr("Clear History")
			value: editable ? qsTr("Press to clear") : qsTr("Clearing")
			cornerMark: false

			VBusItem {
				id: clear
				bind: Utils.path(bindPrefix, "/History/Clear")
			}

			VBusItem {
				id: prodId;
				bind: Utils.path(bindPrefix, "/ProductId")
			}

			VBusItem {
				id: connection;
				bind: Utils.path(bindPrefix, "/Mgmt/Connection")
			}

			Timer {
				id: timer
				interval: 2000
			}
			editable: !timer.running

			onClicked: {
				/*
				 * Write some value to the item as the clear command does not need
				 * to have a value. Do make sure to only write the value when the
				 * button is pressed and not when released.
				 */
				clear.setValue(1)
				timer.start()
			}

			show: showClear()

			function showClear()
			{
				/* If we don't know return false */
				if (!prodId.valid || !connection.valid)
					return false;

				switch (prodId.value)
				{
				case 0x0141:	/* Lynx-shunt */
					return true
	/*
				case 0x0200:	// BMV-600S
				case 0x0201:	// BMV-602S
				case 0x0202:	// BMV-600H
				case 0x0203:	// BMV-700
				case 0x0204:	// BMV-702
				case 0x0205:	// BMV-700H
					// Only VE.Direct (to USB)
					return connection.value.search("CAN") === -1
	*/
				}
				return false
			}
		}
	}
}
