import QtQuick 1.1
import "utils.js" as Utils

MbPage {
	id: root

	property string bindPrefix: "com.victronenergy.settings"
	property variant availableBatteryMonitors: availableBatteryServices.valid ? availableBatteryServices.value : ""
	property string autoSelectedMonitorName: autoSelectedBatteryService.valid ? autoSelectedBatteryService.value : "---"
	property VBusItem availableBatteryServices: VBusItem { bind: Utils.path("com.victronenergy.system", "/AvailableBatteryMeasurements") }
	property VBusItem autoSelectedBatteryService: VBusItem { bind: Utils.path("com.victronenergy.system", "/AutoSelectedBatteryService") }

	title: qsTr("Conditions")

	onAvailableBatteryMonitorsChanged: {
		if (availableBatteryMonitors !== "")
			monitorService.possibleValues = getMonitorList(availableBatteryMonitors)
	}

	function getMonitorList(list)
	{
		var fullList = []
		var component = Qt.createComponent("MbOption.qml");
		for (var i in list) {
			var params = {
				"description": list[i],
				"value": i
			}
				var option = component.createObject(root, params)
				fullList.push(option)
		}
		return fullList
	}

	model: VisualItemModel {

		MbItemOptions {
			id: monitorService
			description: qsTr("Battery monitor")
			bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/BatteryService")
			unknownOptionText: qsTr("Unavailable monitor, set another")
		}

		// Name is not available from "/AutoSelectedBatteryMeasurement"
		// As it is the same, get the autoselected battery monitor name from
		// "/AutoSelectedBatteryService".
		// TODO: Get auto selected service name from *BatteryMeasurement*.
		MbItemText {
			text: qsTr("Auto selected: %1").arg(autoSelectedMonitorName)
			wrapMode: Text.WordWrap
			horizontalAlignment: Text.AlignLeft
			show: monitorService.value === "default"
		}

		MbItemOptions {
			description: qsTr("On loss of communication")
			bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/OnLossCommunication")
			possibleValues: [
				MbOption{description: qsTr("Stop generator"); value: 0},
				MbOption{description: qsTr("Start generator"); value: 1},
				MbOption{description: qsTr("Keep generator running"); value: 2}
			]
		}

		GeneratorCondition {
			description: qsTr("Battery SOC")
			bindPrefix: Utils.path(root.bindPrefix, "/Settings/Generator0/Soc")
			startValueIsGreater: false
			decimals: 0
			unit: "%"
		}

		GeneratorCondition {
			description: qsTr("Battery current")
			name: qsTr("battery current")
			bindPrefix: Utils.path(root.bindPrefix, "/Settings/Generator0/BatteryCurrent")
			unit: "A"
		}

		GeneratorCondition {
			description: qsTr("Battery voltage")
			name: qsTr("battery voltage")
			bindPrefix: Utils.path(root.bindPrefix, "/Settings/Generator0/BatteryVoltage")
			startValueIsGreater: false
			unit: "V"
		}

		GeneratorCondition {
			description: qsTr("AC load")
			bindPrefix: Utils.path(root.bindPrefix, "/Settings/Generator0/AcLoad")
			decimals: 0
			stepSize: 5
			unit: "W"
		}

		GeneratorCondition {
			description: qsTr("Inverter high temperature")
			enableDescription: qsTr("Start on high temperature warning")
			startTimeDescription: qsTr("Start when warning is active for")
			stopTimeDescription: qsTr("When warning is cleared stop after")
			bindPrefix: Utils.path(root.bindPrefix, "/Settings/Generator0/InverterHighTemp")
		}

		GeneratorCondition {
			description: qsTr("Inverter overload")
			enableDescription: qsTr("Start on overload warning")
			startTimeDescription: qsTr("Start when warning is active for")
			stopTimeDescription: qsTr("When warning is cleared stop after")
			bindPrefix: Utils.path(root.bindPrefix, "/Settings/Generator0/InverterOverload")
		}

		MbSubMenu {
			description: qsTr("Periodic test run")
			item {
				bind: Utils.path(root.bindPrefix, "/Settings/Generator0/TestRun/Enabled")
				text: item.value === 1 ? qsTr("Enabled") : qsTr("Disabled")
			}
			subpage:  PageGeneratorTestRun {}
		}
	}
}
