import QtQuick 1.1

MbPage {
	id: root

	property variant service
	property string bindPrefix

	title: getTitle()
	summary: state.text

	function getTitle() {
		/* Show battery suffix so we can distinquish the Lynx Ions battery
		 * function from the bms function. It is done here because of translation. */
		if (productId.valid && productId.value === 0xA130)
			return service.description + qsTr(" (bms)");
		return service.description;
	}

	VBusItem {
		id: productId
		bind: service.path("/ProductId")
	}

	model: VisualItemModel {
		MbItemOptions {
			id: state
			description: qsTr("State")
			bind: service.path("/State")
			readonly: true
			possibleValues:[
				MbOption{description: qsTr("Initializing"); value: 0},
				MbOption{description: qsTr("Initializing"); value: 1},
				MbOption{description: qsTr("Initializing"); value: 2},
				MbOption{description: qsTr("Initializing"); value: 3},
				MbOption{description: qsTr("Initializing"); value: 4},
				MbOption{description: qsTr("Initializing"); value: 5},
				MbOption{description: qsTr("Initializing"); value: 6},
				MbOption{description: qsTr("Initializing"); value: 7},
				MbOption{description: qsTr("Initializing"); value: 8},
				MbOption{description: qsTr("Running"); value: 9},
				MbOption{description: qsTr("Error"); value: 10},
				MbOption{description: qsTr("Error"); value: 11}
			]
		}

		MbItemOptions {
			id: systemSwitch
			description: qsTr("System Switch")
			bind: service.path("/SystemSwitch")
			readonly: true
			possibleValues:[
				MbOption{description: qsTr("Disabled"); value: 0},
				MbOption{description: qsTr("Enabled"); value: 1}
			]
		}

		MbItemOptions {
			description: qsTr("Balancing")
			bind: service.path("/Balancing")
			readonly: true
			possibleValues:[
				MbOption{description: qsTr("Inactive"); value: 0},
				MbOption{description: qsTr("Active"); value: 1}
			]
		}

		MbItemValue {
			description: qsTr("Minimum cell voltage")
			item.bind: service.path("/System/MinCellVoltage")
		}

		MbItemValue {
			description: qsTr("Maximum cell voltage")
			item.bind: service.path("/System/MaxCellVoltage")
		}

		MbSubMenu {
			id: diagnosticItem
			description: qsTr("Diagnostics")
			subpage: Component {
				PageLynxIonDiagnostics {
					title: diagnosticItem.description
					bindPrefix: root.bindPrefix
				}
			}
		}

		MbSubMenu {
			id: historyItem
			description: qsTr("History")
			subpage: Component {
				PageLynxIonHistory {
					title: historyItem.description
					bindPrefix: root.bindPrefix
				}
			}
		}

		MbSubMenu {
			description: qsTr("IO")
			subpage: Component {
				PageLynxIonIo {
					title: qsTr("IO")
					bindPrefix: root.bindPrefix
				}
			}
		}

		MbSubMenu {
			description: qsTr("System")
			subpage:  Component {
				PageLynxIonSystem {
					title: qsTr("System")
					bindPrefix: root.bindPrefix
				}
			}
		}

		MbSubMenu {
			id: deviceItem
			description: qsTr("Device")
			subpage: Component {
				PageDeviceInfo {
					title: deviceItem.description
					bindPrefix: root.bindPrefix
				}
			}
		}
	}
}
