import QtQuick 1.1
import com.victron.velib 1.0
import "utils.js" as Utils

MbPage {
	title: qsTr("Settings")
	property string bindPrefix: "com.victronenergy.settings"

	model: VisualItemModel {
		MbSubMenu {
			id: generalItem
			description: qsTr("General")
			subpage: Component {
				PageSettingsGeneral {
					title: generalItem.description
				}
			}
		}

		MbSubMenu {
			description: qsTr("Firmware")
			subpage: Component {
				PageSettingsFirmware {
					title: qsTr("Firmware")
				}
			}
		}

		MbSubMenu {
			description: qsTr("Date & Time")
			subpage: Component {
				PageTzInfo {
					title: qsTr("Date & Time")
				}
			}
		}

		MbSubMenu {
			description: qsTr("Remote Console")
			subpage: Component { PageSettingsRemoteConsole {} }
		}

		MbSubMenu {
			id: systemSetupItem
			description: qsTr("System setup")
			subpage: Component {
				PageSettingsSystem {
					title: systemSetupItem.description
				}
			}
		}

		MbSubMenu {
			id: displayItem
			description: qsTr("Display & language")
			subpage: Component {
				PageSettingsDisplay {
					title: displayItem.description
				}
			}
		}

		MbSubMenu {
			id: vrmLoggerItem
			description: qsTr("VRM online portal")
			subpage: Component {
				PageSettingsLogger {
					title: vrmLoggerItem.description
				}
			}
		}

		MbSubMenu {
			show: App.withQwacs
			description: qsTr("Wireless AC sensors")
			subpage: Component { PageSettingsQwacs {} }
		}

		MbSubMenu {
			description: qsTr("Wired AC sensors")
			subpage: Component { PageSettingsCGwacsOverview {} }
		}

		MbSubMenu {
			description: qsTr("Fronius PV inverters")
			subpage: Component { PageSettingsFronius {} }
		}

		MbSubMenu {
			description: qsTr("Hub-4")
			subpage: Component { PageSettingsHub4 {} }
		}

		MbSubMenu {
			id: ethernetItem
			description: qsTr("Ethernet")
			subpage: Component { PageSettingsTcpIp {} }
		}

		MbSubMenu {
			description: qsTr("Wi-Fi")
			subpage: Component { PageSettingsWifi {} }
		}

		MbSubMenu {
			description: qsTr("GPS")
			subpage: Component { PageSettingsGps {} }
		}

		MbSubMenu {
			description: qsTr("Generator start/stop")
			subpage: Component { PageGenerator {} }
		}

		MbSubMenu {
			description: qsTr("Tank pump")
			subpage: Component { PageSettingsTankPump {} }
		}

		MbSubMenu {
			description: qsTr("Relay")
			subpage: Component { PageSettingsRelay {} }
		}

		MbSubMenu {
			description: qsTr("Services")
			subpage: Component { PageSettingsServices {} }
		}

		MbSubMenu {
			// TODO: Find a better way to check if
			// analog inputs are available on the device
			property VBusItem ioSettings: VBusItem {
				bind: Utils.path(bindPrefix,
								 "/Settings/AnalogInput/Resistive/1/Function")
			}
			description: qsTr("I/O")
			subpage: Component { PageSettingsIo {} }
			show: ioSettings.valid
		}

		MbSubMenu {
			description: qsTr("Debug")
			subpage: Component { PageDebug {} }
			show: ColorControl.accessLevel >= Victron.AccessService
		}
	}
}
