import QtQuick 1.1
import com.victron.velib 1.0
import "utils.js" as Utils

MbPage {
	id: root
	property string bindPrefix: "com.victronenergy.settings"
	property VBusItem autoUpdate: VBusItem { bind: Utils.path(bindPrefix, "/Settings/System/AutoUpdate")}

	model: VisualItemModel {
		MbItemValue {
			description: qsTr("Firmware version")
			item.value: ColorControl.version
		}

		MbItemValue {
			description: qsTr("Build date/time")
			item.value: ColorControl.versionDate
		}

		MbSubMenu {
			description: qsTr("Online updates")
			subpage: Component {
				MbPage {
					property string bindPrefix: "com.victronenergy.settings"

					title: qsTr("Online updates")

					model: VisualItemModel {
						MbItemOptions {
							id: autoUpdate
							description: qsTr("Auto update")
							bind: Utils.path(bindPrefix, "/Settings/System/AutoUpdate")
							writeAccessLevel: Victron.AccessUser
							possibleValues: [
								MbOption{description: qsTr("Disabled"); value: 0},
								MbOption{description: qsTr("Check only"); value: 2},
								MbOption{description: qsTr("Check and download only"); value: 3; readonly: true},
								MbOption{description: qsTr("Check and update"); value: 1}
							]
						}

						MbItemOptions {
							description: qsTr("Update to")
							bind: Utils.path(bindPrefix, "/Settings/System/ReleaseType")
							possibleValues: [
								MbOption{description: qsTr("Latest release"); value: Victron.FirmwareRelease},
								MbOption{description: qsTr("Latest release candidate"); value: Victron.FirmwareCandidate},
								MbOption{description: qsTr("Testing"); value: Victron.FirmwareTesting; readonly: ColorControl.accessLevel < Victron.AccessService},
								MbOption{description: qsTr("Develop"); value: Victron.FirmwareDevelop; readonly: true}
							]
						}

						MbOK {
							id: checkUpdates
							description: qsTr("Check for updates")
							value: qsTr("Press to check")
							editable: !Updater.running && !Updater.runningOffline && !Updater.updateTriggered
							writeAccessLevel: Victron.AccessUser
							onClicked: Updater.checkUpdates()
						}

						MbOK {
							id: installUpdate
							description: qsTr("Update available")
							value: (Updater.running || Updater.status === 2) && Updater.status !== 0 ?
									   Updater.statusDescription : qsTr("Press to update to %1").arg(Updater.availableUpdate)
							editable: !Updater.running && !Updater.runningOffline && !Updater.updateTriggered
							writeAccessLevel: Victron.AccessUser
							onClicked: Updater.doUpdate()
							show: Updater.availableUpdate !== ""
						}

						MbItemValue {
							description: qsTr("Update build date/time")
							item.value: Updater.availableUpdateBuild
							show: installUpdate.visible && ColorControl.accessLevel >= Victron.AccessSuperUser
						}
					}

					Timer {
						id: holdStatus
						interval: 10000
						onTriggered: checkUpdates.value = qsTr("Press to check")
					}

					Connections {
						target: Updater
						onStatusChanged: {
							if (Updater.running && !Updater.updateTriggered) {
								holdStatus.restart()
								checkUpdates.value = Updater.status === 0 && Updater.availableUpdate === "" ?
											qsTr("No newer version available") :
											Updater.status === 0 ? qsTr("Press to check") :
																   Updater.statusDescription
							}
						}
					}
				}
			}
		}

		MbSubMenu {
			description: qsTr("Offline updates")
			subpage: Component {
				MbPage {

					title: qsTr("Offline updates")

					model: VisualItemModel {
						MbOK {
							id: checkUpdates
							description: qsTr("Check for updates on SD/USB")
							value: qsTr("Press to check")
							editable: !Updater.running
							writeAccessLevel: Victron.AccessUser
							onClicked: Updater.checkOfflineUpdates()
						}

						MbOK {
							id: installUpdate
							description: qsTr("Update available")
							value: (Updater.running || Updater.status === 2) && Updater.status !== 0 ?
									   Updater.statusDescription : qsTr("Press to update to %1").arg(Updater.offlineAvailableUpdate)
							editable: !Updater.running && !Updater.runningOffline && !Updater.updateTriggered
							writeAccessLevel: Victron.AccessUser
							onClicked: Updater.doOfflineUpdate()
							show: Updater.offlineAvailableUpdate !== ""
						}

						MbItemValue {
							description: qsTr("Update build date/time")
							item.value: Updater.offlineAvailableUpdateBuild
							show: installUpdate.visible && ColorControl.accessLevel >= Victron.AccessSuperUser
						}
					}

					Timer {
						id: holdStatus
						interval: 10000
						onTriggered: checkUpdates.value = qsTr("Press to check")
					}

					Connections {
						target: Updater
						onStatusChanged: {
							if (Updater.runningOffline && !Updater.updateTriggered) {
								holdStatus.restart()
								checkUpdates.value = Updater.status === 0 && Updater.offlineAvailableUpdate === "" ?
											qsTr("No newer version found") :
											Updater.status === 0 ? qsTr("Press to check") :
																   Updater.statusDescription
							}
						}
					}
				}
			}
		}

		MbSubMenu {
			description: qsTr("Stored backup firmware")
			subpage: Component {
				PageSettingsRootfsSelect {

				}
			}
		}
	}
}
