import QtQuick 1.1
import com.victron.velib 1.0
import "utils.js" as Utils

MbPage {
	title: qsTr("Fronius PV inverters")
	property string settings: "com.victronenergy.settings"
	property string gateway: "com.victronenergy.fronius"

	VBusItem {
		id: autoDetectItem
		bind: Utils.path(gateway, "/AutoDetect")
	}

	VBusItem {
		id: scanProgressItem
		bind: Utils.path(gateway, "/ScanProgress")
	}

	model: VisualItemModel {
		MbSubMenu {
			id: menuInverters
			description: qsTr("Inverters")
			subpage: Component {
				PageSettingsFroniusInverters { }
			}
		}

		MbOK {
			description: qsTr("Data card search")
			value: autoDetectItem.value ? qsTr("Scanning") + " " + scanProgressItem.text : qsTr("Press to scan")
			writeAccessLevel: Victron.AccessUser
			onClicked: autoDetectItem.setValue(autoDetectItem.value === 0 ? 1 : 0)
		}

		MbSubMenu {
			description: qsTr("Detected data cards")
			subpage: Component {
				PageSettingsFroniusShowIpAdressess { }
			}
		}

		MbSubMenu {
			description: qsTr("Add data cards manually")
			subpage: Component {
				PageSettingsFroniusSetIpAddresses { }
			}
		}

		MbEditBox {
			id: tcpPort
			description: qsTr("TCP port")
			matchString: "0123456789"
			text: portNumberItem.valid ? Utils.pad(portNumberItem.value, 5) : '--'
			onTextChanged: portNumberItem.setValue(parseInt(text, 10));

			VBusItem {
				id: portNumberItem
				bind: Utils.path(settings, "/Settings/Fronius/PortNumber")
			}
		}
	}
}
