import QtQuick 1.1
import com.victron.velib 1.0
import "utils.js" as Utils

MbPage {
	id: root
	title: qsTr("Generator start/stop settings")
	property string settingsBindPrefix: "com.victronenergy.settings"
	property string startStopsettingsBindPrefix: "com.victronenergy.generator.startstop0"

	model: VisualItemModel {

		MbSubMenu {
			id: conditions
			description: qsTr("Conditions")
			subpage:
				Component {
				PageGeneratorConditions {
					title: qsTr("Conditions")
					bindPrefix: root.settingsBindPrefix
				}
			}
		}

		MbSpinBox {
			description: qsTr("Minimum run time")
			bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/MinimumRuntime")
			unit: "m"
			numOfDecimals: 0
			stepSize: 1
		}

		MbSwitch {
			id: timeZones
			name: qsTr("Quiet hours")
			bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/QuietHours/Enabled")
			enabled: valid
			writeAccessLevel: Victron.AccessUser
		}

		MbEditBoxTime {
			description: qsTr("Quiet hours start time")
			bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/QuietHours/StartTime")
			show: timeZones.checked
			writeAccessLevel: Victron.AccessUser
		}

		MbEditBoxTime {
			description: qsTr("Quiet hours end time")
			bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/QuietHours/EndTime")
			show: timeZones.checked
			writeAccessLevel: Victron.AccessUser
		}
		MbOK {
			description: qsTr("Reset daily run time counters")
			value: qsTr("Press to reset")
			enabled: true
			editable: enabled
			onClicked: {
				if (state.value === 0) {
					var now = new Date()
					var today = new Date(Date.UTC(now.getFullYear(), now.getMonth(), now.getDate()))
					var todayInSeconds = today.getTime() / 1000
					resetDaily.setValue('{"%1" : 0}'.arg(todayInSeconds.toString()))
					toast.createToast(qsTr("The daily runtime counter has been reset"))
				} else if (state.value === 1) {
					toast.createToast(qsTr("It is not possible to modify the counters while the generator is running"))
				}
			}

			VBusItem {
				id: resetDaily
				bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/AccumulatedDaily")
			}
		}

		MbEditBox {
			id: setTotalRunTime
			description: qsTr("Generator total run time (hours)")
			text: Math.round(totalRuntime.value / 60 / 60)
			matchString: "0123456789"
			maximumLength: 6
			ignoreChars: "h"
			enabled: state.value === 0
			onTextChanged: totalRuntime.setValue(parseInt(text, 10)  * 60 * 60)

			VBusItem {
				id: totalRuntime
				bind: Utils.path(settingsBindPrefix, "/Settings/Generator0/AccumulatedTotal")
			}

			Keys.onSpacePressed: {
				if (!enabled)
					toast.createToast(qsTr("It is not possible to modify the counters while the generator is running"))
			}
		}
	}

	VBusItem {
		id: state
		bind: Utils.path(startStopsettingsBindPrefix, "/State")
	}
}
